@@ -18,11 +18,11 @@
  */
 #include <kjs/lookup.h>
 
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include "kiledebug.h"
 #include <kinputdialog.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kstandarddirs.h>
 
 #include <signal.h>
@@ -42,7 +42,7 @@
 #include "kileviewmanager.h"
 #include "editorkeysequencemanager.h"
 
-// Modified declaration from <khtml/ecma/kjs_proxy.h>
+// Modified declaration from <tdehtml/ecma/kjs_proxy.h>
 // Acknowledgements go to:
 //  Copyright (C) 1999 Harri Porten (porten@kde.org)
 //  Copyright (C) 2001 Peter Kelly (pmk@post.com)
@@ -58,7 +58,7 @@ private:
   itimerval oldtv;
 };
 
-// Modified implementation originating from <khtml/ecma/kjs_proxy.cpp>
+// Modified implementation originating from <tdehtml/ecma/kjs_proxy.cpp>
 // Acknowledgements go to:
 // Copyright (C) 1999-2001 Harri Porten (porten@kde.org)
 // Copyright (C) 2001,2003 Peter Kelly (pmk@post.com)
@@ -85,7 +85,7 @@ void KJSCPUGuard::alarmHandler(int) {
 
 
 namespace KJS {
-// Taken from <khtml/ecma/kjs_binding.cpp>
+// Taken from <tdehtml/ecma/kjs_binding.cpp>
 // Acknowledgements go to:
 // Copyright (C) 1999-2003 Harri Porten (porten@kde.org)
 // Copyright (C) 2001-2003 David Faure (faure@kde.org)
@@ -400,13 +400,13 @@ namespace KileJScript {
 
 ////////////////////////////// JScript //////////////////////////////
 
-/* The IDs of the scripts are used to maintain correct bindings with KAction objects, i.e. for example, we
+/* The IDs of the scripts are used to maintain correct bindings with TDEAction objects, i.e. for example, we
  * want to make sure the action script_execution_0 always refers to same script (the script with id 0 !), even
  * after reloading all the scripts.
  */
 
 	JScript::JScript(unsigned int id, const TQString& file) : m_id(id), m_file(file), m_action(NULL) {
-		m_name = KGlobal::dirs()->relativeLocation("appdata", file);
+		m_name = TDEGlobal::dirs()->relativeLocation("appdata", file);
 		if(m_name.startsWith("scripts")) {
 			m_name = m_name.mid(8); // remove "scripts" + path separator
 		}
@@ -445,15 +445,15 @@ namespace KileJScript {
 		m_id = id;
 	}
 
-	void JScript::setActionObject(KAction* action) {
+	void JScript::setActionObject(TDEAction* action) {
 		m_action = action;
 	}
 
-	const KAction* JScript::getActionObject() const {
+	const TDEAction* JScript::getActionObject() const {
 		return m_action;
 	}
 
-	KAction* JScript::getActionObject() {
+	TDEAction* JScript::getActionObject() {
 		return m_action;
 	}
 
@@ -508,7 +508,7 @@ namespace KileJScript {
 
 ////////////////////////////// Manager //////////////////////////////
 
-	Manager::Manager(KileInfo *kileInfo, KConfig *config, KActionCollection *actionCollection, TQObject *parent, const char *name)  : TQObject(parent, name), m_jScriptDirWatch(NULL), m_kileInfo(kileInfo), m_config(config), m_actionCollection(actionCollection) {
+	Manager::Manager(KileInfo *kileInfo, TDEConfig *config, TDEActionCollection *actionCollection, TQObject *parent, const char *name)  : TQObject(parent, name), m_jScriptDirWatch(NULL), m_kileInfo(kileInfo), m_config(config), m_actionCollection(actionCollection) {
 		// create a local scripts directory if it doesn't exist yet
 		m_localJScriptDir = locateLocal("appdata", "scripts/", true);
 		m_jScriptDirWatch = new KDirWatch(this, "KileJScript::Manager::JScriptDirWatch");
@@ -586,7 +586,7 @@ m_kileInfo->viewManager()->currentView()->down();*/
 		}
 		m_config->setGroup(TQString());
 
-		TQStringList scriptFileNamesList = KGlobal::dirs()->findAllResources("appdata", "scripts/*.js", true, true);
+		TQStringList scriptFileNamesList = TDEGlobal::dirs()->findAllResources("appdata", "scripts/*.js", true, true);
 		for(TQStringList::iterator i = scriptFileNamesList.begin(); i != scriptFileNamesList.end(); ++i) {
 			registerScript(*i, pathIDMap, takenIDMap, maxID);
 		}
@@ -606,7 +606,7 @@ m_kileInfo->viewManager()->currentView()->down();*/
 		m_idScriptMap.clear();
 		m_kileInfo->editorKeySequenceManager()->removeKeySequence(keySequenceList);
 		for(TQValueList<JScript*>::iterator it = scriptList.begin(); it != scriptList.end(); ++it) {
-			KAction *action = (*it)->getActionObject();
+			TDEAction *action = (*it)->getActionObject();
 			if(action) {
 				action->unplugAll();
 				delete action;
@@ -692,7 +692,7 @@ m_kileInfo->viewManager()->currentView()->down();*/
 	}
 
 	void Manager::populateDirWatch() {
-		TQStringList jScriptDirectories = KGlobal::dirs()->findDirs("appdata", "scripts");
+		TQStringList jScriptDirectories = TDEGlobal::dirs()->findDirs("appdata", "scripts");
 		for(TQStringList::iterator i = jScriptDirectories.begin(); i != jScriptDirectories.end(); ++i) {
 			// FIXME: future KDE versions could support the recursive
 			//        watching of directories out of the box.
@@ -776,7 +776,7 @@ m_kileInfo->viewManager()->currentView()->down();*/
 	}
 ////////////////////////////// ScriptExecutionAction //////////////////////////////
 
-	ScriptExecutionAction::ScriptExecutionAction(unsigned int id, KileJScript::Manager *manager, KActionCollection* parent) : KAction(TQString(), KShortcut(), NULL, NULL,  parent, TQString("script_execution_" + TQString::number(id)).ascii()), m_manager(manager), m_id(id) {
+	ScriptExecutionAction::ScriptExecutionAction(unsigned int id, KileJScript::Manager *manager, TDEActionCollection* parent) : TDEAction(TQString(), TDEShortcut(), NULL, NULL,  parent, TQString("script_execution_" + TQString::number(id)).ascii()), m_manager(manager), m_id(id) {
 		const KileJScript::JScript *script = m_manager->getScript(m_id);
 		Q_ASSERT(script);
 		setText(i18n("Execution of %1").arg(script->getName())); 
